#
# spec file for package MyODBC-unixODBC
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           MyODBC-unixODBC
Version:        5.1.8
Release:        22.5
%define         manager unixODBC
Summary:        ODBC Interface for Communication with MySQL Compiled with UnixODBC
License:        SUSE-GPL-2.0-with-FLOSS-exception
Group:          Productivity/Databases/Tools
Url:            http://www.mysql.com/products/myodbc/index.html
Source0:        mysql-connector-odbc-%{version}.tar.gz
Source1:        odbcinst.ini.%{manager}.sample
Source2:        odbc.ini.%{manager}.sample
Source3:        README
Source100:      MyODBC-unixODBC-rpmlintrc
Patch1:         MyODBC-unixODBC-my_free.patch
Patch3:         MyODBC-unixODBC-64bit.patch
Patch4:         MyODBC-unixODBC-my_init_dynamic_array_flags.patch
Patch5:         MyODBC-unixODBC-my_malloc_when_using_my_free.patch
Patch6:         MyODBC-unixODBC-is_minimum_version.patch
Patch7:         MyODBC-unixODBC-remove_use_of_test_macro.patch
BuildRequires:  libtool
BuildRequires:  mysql-devel
BuildRequires:  unixODBC-devel
Supplements:    packageand(unixODBC:mysql-shared)
Obsoletes:      MyODBC-libiodbc < %{version}
Provides:       MyODBC-libiodbc = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
MyODBC is an interface for communication with MySQL. It is one of the
most popular ODBC drivers in the open source market, used by many users
to access the MySQL functionality. It is compiled with unixODBC.

%prep
%setup -q -n mysql-connector-odbc-%{version}
%patch1 -p1
%patch3 -p1
if grep -l 'my_init_dynamic_array(A,B,C,D,E)' /usr/include/mysql/my_sys.h; then
%patch4
fi
%patch5 -p1
%patch6 -p1
%patch7 -p1

%build
# mysql 5.5.10 has stopped #define'ing THREAD in its exports, and has
# started #define'ing MY_PTHREAD_FASTMUTEX, and neither of those changes
# sit well with mysql-connector-odbc 5.1.8.  Revisit need for these hacks
# when updating to newer release.
export CFLAGS="%{optflags} -fno-strict-aliasing -DTHREAD=1 -UMY_PTHREAD_FASTMUTEX"

autoreconf -fi
%configure \
    --with-mysql-libs=%{_libdir}/mysql \
    --with-mysql-includes=%{_includedir}/mysql \
    --with-unixODBC=%{_prefix} \
    --with-odbc-ini=%{_sysconfdir}/%{manager}/odbc.ini \
    --disable-gui --disable-test

make %{?_smp_mflags}

%install
make "DESTDIR=%{buildroot}" install

# documentation
install -d -m 755 %{buildroot}/%{_defaultdocdir}/%{name}/
install -m 644 {ChangeLog,README,README.debug,INSTALL,LICENSE.gpl} %{buildroot}/%{_defaultdocdir}/%{name}/
rm %{buildroot}/%{_datadir}/mysql-connector-odbc/{ChangeLog,README,README.debug,INSTALL,LICENSE.gpl}

# samples
mkdir %{buildroot}/%{_defaultdocdir}/%{name}/ini/
sed -e 's/@driverpath@/\/usr\/%{_lib}\/%{manager}/g' -e 's/@version@/%{version}/g' %{SOURCE1} >%{buildroot}/%{_defaultdocdir}/%{name}/ini/odbcinst.ini.sample
sed -e 's/@driverpath@/\/usr\/%{_lib}\/%{manager}/g' -e 's/@version@/%{version}/g' %{SOURCE2} >%{buildroot}/%{_defaultdocdir}/%{name}/ini/odbc.ini.sample
install -m 644 %{SOURCE3} %{buildroot}/%{_defaultdocdir}/%{name}/ini/

# remove .la files
rm %{buildroot}/%{_libdir}/*.la

%files
%defattr(-,root,root)
%doc %{_defaultdocdir}/%{name}/
%{_bindir}/myodbc-installer
%{_libdir}/lib*so

%changelog
* Wed May 13 2015 kmroz@suse.com
- test() macro is undefined in libmyodbc5.so and is also not found
  in libmysqlclient. Port changes found in v5.2 and beyond to prevent:
  isql: symbol lookup error: /usr/lib64/libmyodbc5.so: undefined
  * added: MyODBC-unixODBC-remove_use_of_test_macro.patch
* Mon May 11 2015 kmroz@suse.com
- Backport fix from v5.2.3 related to incorrect implementation of
  is_minimum_version().
  * added MyODBC-unixODBC-is_minimum_version.patch
* Fri Feb 20 2015 kmroz@suse.com
- Fix segfault in myodbc-install when freeing pointer (allocated with
  basic malloc()) using x_free()/my_free(). my_free() accesses 8 bytes
  before the pointer returned by malloc(), hence my_malloc() is needed.
  (Bug#881624)
  * added MyODBC-unixODBC-my_malloc_when_using_my_free.patch
* Mon Mar  3 2014 mhrusecky@suse.cz
- fixing build against MariaDB 10
  * added MyODBC-unixODBC-my_init_dynamic_array_flags.patch
* Mon Jan 28 2013 mhrusecky@suse.cz
- disabling building of test library as it is broken and we don't
  ship it anyway
* Tue Jun 19 2012 cfarrell@suse.com
- license update: SUSE-GPL-2.0-with-FLOSS-exception
  SPDX format (or use the spreadsheet linked at http://license.opensuse.org
  if there is no entry on http://www.spdx.org/licenses)
* Tue Nov 15 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Wed Jun  1 2011 idonmez@novell.com
- Don't make libmyodbc5 a separate library, its has a wrong soname,
  and internal
* Mon May 30 2011 idonmez@novell.com
- Fix provides/obsoletes on MyODBC-libiodbc
* Thu May 26 2011 idonmez@novell.com
- Updated to version 5.1.8,
  see /usr/share/doc/packages/MyODBC-unixODBC/ChangeLog
- Disable GUI since other distributions dropped it and its outdated
- Drop outdated patches:
  * MyODBC-3.51.26r1127.diff
  * MyODBC-unixODBC-my_bool-cleanup.patch
- Add new patches from Fedora to fix compile against MySQL 5.5
  * MyODBC-unixODBC-my_free.patch
  * MyODBC-unixODBC-add-mysys.patch
  * MyODBC-unixODBC-64bit.patch
* Wed Dec  2 2009 coolo@novell.com
- update patch to fix build
* Mon Nov 30 2009 crrodriguez@opensuse.org
- use %%configure to fix RPM_OPT_FLAGS usage on C++ code
* Wed Nov 18 2009 mhrusecky@suse.cz
- fixed setup registration (bnc#552330)
* Tue Aug  4 2009 mhrusecky@suse.cz
- using my_bool instead of bool (fixed compilation error)
* Tue Feb  3 2009 mhrusecky@suse.cz
- updated to version 3.51.27r695
  Bugs fixed:
  * Cannot use ssl (Bug #29955)
  * Enable auto reconnect doesn't work (Bug #37179)
  * Add read and write timeouts on the connection (Bug #40407)
- automatic installation and deinstallation (bnc#420817)
- using current version number in sample files
* Tue Jul 15 2008 anosek@suse.cz
- updated to version 3.51.26r1127
  Bugs fixed:
  * Access Violation in myodbc3.dll (Bug #30770)
  * Truncation of "SHOW CREATE TABLE" result (Bug #24131)
  * Added a new connection option FLAG_NO_BINARY_RESULT. Fixed
    field type charset 63 problem. (Bug #29402)
- fixed Database Can Not Connect to a MySQL due to missing files (bnc#144602)
  - added Supplements: packageand(unixODBC:mysql-shared) into spec file
* Thu Jun  5 2008 anosek@suse.cz
- updated to version 3.51.25r1093
  Bugs fixed:
  * SQL_DESC_FIXED_PREC_SCALE was possibly being reported as true, but it's
    never supported. (Bug #35581)
  * ADO failed to retrieve the length of LONGBLOB columns. (Bug #12805)
  * ConfigDSN() returned FALSE when the dialog was cancelled by the user.
  * Static cursor was unable to be used through ADO when dynamic cursors
    were enabled. (Bug #27351)
  * Driver would crash when requesting the current catalog before connecting.
    (Bug #16653)
  * Catalog data was truncated due to NAME_LEN only allocating a single byte
    for characters. (Bug #32864)
  * SSL connections could not be established properly. Added the server
    certificate verification flag. (Bug #29955)
  * Added deprecated SQLSetParam function. (Bug #29871)
  * Recordset-based update fails if blob field is queried. (Bug #19065)
  * Allows dirty reading with SQL_TXN_READ_COMMITTED isolation through ODBC
    (Bug #31959)
  * Don't cache results and SQLExtendedFetch work badly together.
    (Bug #32420)
  * SQLFetch or SQLFetchScroll returns negative data length using SQL_C_WCHAR.
    (Bug #31220)
  * An SQLSTATE of HY000 was returned when a stored procedure was not found,
    instead of 42000. This caused problems with ADO's adCmdUnknown option.
    (Bug #27158)
  * Identifiers were quoted incorrectly by SQLColumns(). (Bug #32989)
  * Worked around bug in iODBC installer library that made it impossible
    to create a system DSN, particularly on Mac OS X, where the installer
    created the /Library/ODBC/*.ini files with insufficient permissions.
    (Bug #31495)
  * Unresolved symbols "min" and "max" in libmyodbc3.so w/gcc 4.2.
    (Bug #34256)
  * Fixed some incorrect information returned by SQLGetTypeInfo().
    (Bug #30918)
  * Values bound using the SQL_C_CHAR value type but with numeric
    parameter type were not correctly escaped. (Bug #34575)
  * The driver reported that it does not support SQLProcedureColumns(),
    which causes problems for ADO. (Bug #33298)
- fixed ODBC setup library for mysql is missing in distribution (bnc#336135)
  - added --enable-gui parameter to configure
  - added build dependency qt3-devel
- dropped obsoleted patch (compile.patch)
* Wed Feb 27 2008 anosek@suse.cz
- updated to version 3.51.23r998
  Functionality added or changed:
  * Removed workaround for bug #10491 in the server, which has now been
    fixed in MySQL Server 5.0.48 and 5.1.21.
  * Added FLAG_COLUMN_SIZE_S32 to limit the reported column size to a
    signed 32-bit integer. This option is automatically enabled for ADO
    applications, in order to work around a bug in ADO. (Bug #13776)
  Bugs fixed:
  * Allowed connections to be enlisted in distributed transactions, even
    though the driver doesn't support them. (Bug #32727)
  * Cleaning up environment handles in multithread environments could result
    in a five (or more) second delay. (Bug #32366)
  * SQLAllocStmt() and SQLFreeStmt() did not synchronize access to the
    list of statements associated with a connection. (Bug #32857)
  * SQLGetInfo() returned the wrong value for SQL_DATABASE_NAME when no
    database was selected. (Bug #3780)
  * Changing the DSN name when editing a DSN left behind the DSN
    under the old name in addition to creating the new entry. (Bug #31165)
  * SQLGetInfo() reported that UNION was not supported. (Bug #32253)
  * The non-portable "English" locale was used for handling of decimal
    and floating-point values instead of "C". (Bug #32294)
  * Unsigned integer values greater than the maximum value of a signed
    integer were handled incorrectly. (Bug #32171)
  * The wrong result was returned by SQLGetData() when the data was an
    empty string and a zero-sized buffer was specified. (Bug #30958)
- dropped obsoleted patch (setlocale.patch)
- added patch (compile.patch)
* Wed Nov 14 2007 anosek@suse.cz
- updated to version 3.51.21r807
  Functionality added or changed:
  * Because of Bug #10491 in the server, character string results were
    sometimes incorrectly identified as SQL_VARBINARY. Until this server
    bug is corrected, the driver will identify all variable-length
    strings as SQL_VARCHAR.
  * An experimental binary package, without an installer, is available
    for Microsoft Windows x64 Edition.
  * Binary packages as disk images with installers are now available
    for Mac OS X.
  * Binary packages for Sun Solaris are available as PKG packages.
  * Added FLAG_MULTI_STATEMENTS to allow issuing queries that contain
    multiple statements. Also added to the setup GUI. (Bug #7445)
  * Removed support for the TRACE and TRACEFILE DSN options. The standard
    ODBC logging should be used.
  * Added support for SQL_ATTR_ROW_BIND_OFFSET_PTR in normal cursors.
    (Bug #6741)
  * Added SSL options to the GUI setup dialog.
  Lots of bugfixes
* Thu Jul 26 2007 anosek@suse.cz
- updated to version 3.51.17r581
  Functionality added or changed:
  * Added an option (CHARSET) for specifying the default character
    set for a connection. This must be used instead of a "SET NAMES"
    statement. Also available from the GUI setup dialog. (Related
    to Bug #6667 and Bug #9498.)
  * Dis-allow NULL ptr for null indicator when calling SQLGetData()
    if value is null. Now returns SQL_ERROR w/state 22002.
  * Fixed calling convention ptr and wrong free in myodbc3i, and fixed
    the null terminating (was only one, not two) when writing DSN to string.
  Bugs fixed:
  * myodbc3i did not correctly format driver info, which could cause the
    installation to fail. (Bug #29709)
  * Multiple result sets were not correctly flushed when a statement
    handle was closed. (Bug #16817)
  * SQLProcedures() did not handle NULL parameters, which could lead to
    crashes (Bug #28316)
  * SQLColumns() did not handle many of its parameters correctly, which
    could lead to incorrect results. The table name argument was not handled
    as a pattern value, and most arguments were not escaped correctly when
    they contained non-alphanumeric characters. (Bug #8860)
  * If there was more than one unique key on a table, the correct fields
    were not used in handling SQLSetPos(). (Bug #10563)
  * SQLColAttribute() returned the wrong value for SQL_DESC_BASE_COLUMN_NAME
    and SQL_DESC_BASE_TABLE_NAME for aliased fields. (Bug #6197)
  * Calling SQLGetDiagField with RecNumber 0,DiagIdentifier
    NOT 0 returns SQL_ERROR (Bug #16224)
  * Correctly return error if SQLBindCol is called with an invalid column
  * Fixed error handling of OOM and bad connections in catalog functions.
    This might raise errors in code paths that had ignored them in the past.
    Gathered the logic for internal result sets into one place. (Bug #26934)
  * Fixed bad use of memory related to setup/util/GUI. (Bug #27315)
  * Added a new DSN "OPTION" (FLAG_ZERO_DATE_TO_MIN) to retrieve XXXX-00-00
    dates as the minimum allowed ODBC date (XXXX-01-01). Added another
    option (FLAG_MIN_DATE_TO_ZERO) to mirror this but for bound parameters.
    FLAG_MIN_DATE_TO_ZERO only changes 0000-01-01 to 0000-00-00. (Bug #13766)
  * Fixed possible crash if SQLBindCol() was not called before SQLSetPos().
    Fixed use of MYSQL structure pertaining to updating large blobs in
    cursors. (Bug #10562)
* Fri Jul 13 2007 anosek@suse.cz
- updated to version 3.51.16r494
  * Added support for using SSL. This is not yet exposed in the setup GUI,
    but must be enabled through configuration files or the DSN. (Bug #12918)
  Bugs fixed:
  * "Out of sync error" or "MySQL Server has gone away" after executing a
    stored procedure (Bug #27544)
  * SQL_C_TYPE_DATE, SQL_C_TYPE_TIME, and SQL_C_TYPE_TIMESTAMP were formatted
    without seperators, which could cause them to get interpreted incorrectly
    in some cases due to server bugs. (Bug #15773)
  * Calls to SQLNativeSql could cause stack corruption due to an incorrect
    pointer cast. (Bug #28758)
  * SQLSetPos could update or delete the wrong rows when the original result
    set did not contain all columns of a multi-part primary key. (Bug #28255)
  * SQLTables() did not distinguish tables from views. (Bug #23031)
  * The wrong function was used for freeing the artificial result sets that
    are created by some catalog functions. (Bug #22797)
  * Accessing the results of catalog functions could cause a crash when the
    "Don't cache results" option was set and a forward-only cursor was
    being used. (Bug #4657)
  * SQL_WVARCHAR and SQL_WLONGVARCHAR parameters were not properly quoted
    and escaped. (Bug #16235)
  * SQLForeignKeys() did not properly escape wildcard characters in its
    table name parameters when retrieving information. (Bug #27723)
  * Calls to SQLSetPos() could cause the driver to incorrectly calculate the
    length of some fields. (Bug #16917)
* Fri May 18 2007 anosek@suse.cz
- updated to version 3.51.15r409
  * Added auto-reconnect option because automatic reconnect is now
    disabled by default in libmysql
  * Added auto is null option (Bug #10910)
  * Added support for SQLMoreResults
  * Checking SQL_ATTR_CONNECTION_DEAD now always calls mysql_ping() to
    check for a dead connection.
  * Remove ODBC escape syntax { and } that begin and terminate statements,
    allowing {CALL (?)} for procedures that don't require OUT or INOUT
    parameters
  * Improved regression tests
  * Added --with-separate-debug-driver ./configure option
  * Lots of bugfixes
- dropped obsoleted patch (stringh.diff)
* Mon Jun 12 2006 mmarek@suse.cz
- use "C", not "English" in setlocale() calls
  [http://www.openoffice.org/issues/show_bug.cgi?id=66283]
  (setlocale.patch)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan  5 2006 mmarek@suse.cz
- update to 3.51.12
- use make -j
* Tue Aug  2 2005 ltinkl@suse.cz
- update to 3.51.11 (#99150)
* Thu Apr 28 2005 schwab@suse.de
- Properly use libltdl.
* Tue Feb  1 2005 ro@suse.de
- update to 3.51.10
* Fri Sep 17 2004 ro@suse.de
- remove hack for libmysqlclient_r (mysql has been fixed)
- remove NoSource tag (MyODBC-libiodbc is no longer present)
* Fri Aug 13 2004 ro@suse.de
- update to 3.51.07
* Thu Feb 26 2004 ltinkl@suse.cz
- obsoletes MyODBC-libiodbc
* Tue Sep 30 2003 ltinkl@suse.cz
- updated to latest stable version (3.51.06)
* Mon Jun 10 2002 prehak@suse.cz
- new package in distribution - version 2.50.39
- fixed variable name ac_hdr to ac_header in acinclude.m4
